# securities-exchange


[![image](https://img.shields.io/pypi/v/securities-exchange.svg)](https://pypi.python.org/pypi/securities-exchange)

**A toy example of a Security Exchange in python**

-   Free software: MIT License
-   Documentation: https://ggnne.github.io/securities-exchange
    

## Features

-   TODO
